Class: Concept::Base

Inherits:
ApplicationRecord show all
Includes:
Validations, Expirable, FirstLevelObjectScopes, FirstLevelObjectValidations, Versioning
Defined in:
app/models/concept/base.rb

Overview

Copyright 2011-2013 innoQ Deutschland GmbH

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Direct Known Subclasses

Collection::Base, Skos::Base, Skos::Scheme

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from FirstLevelObjectValidations

#distinct_versions, #origin_has_to_be_escaped

Methods included from Validations

#exclusive_broader_and_narrower_concepts, #exclusive_hidden_labels_per_concept, #exclusive_pref_and_alt_labels_per_concept, #exclusive_top_term, #no_self_reference_concept_relation, #pref_label_in_primary_thesaurus_language, #rooted_top_terms, #unique_alt_labels, #unique_pref_label_language, #unique_pref_labels, #valid_rank_for_ranked_relations

Methods included from Versioning

#branch, #disable_validations_for_publishing, #editor_selectable?, #enable_validations_for_publishing, #in_review?, #never_published?, #publish, #publish!, #publishable?, #published?, #state, #to_review, #unpublish, #unpublished?, #validatable_for_publishing?, #with_validations_for_publishing

Instance Attribute Details

#reverse_match_serviceObject

Returns the value of attribute reverse_match_service.



18
19
20
# File 'app/models/concept/base.rb', line 18

def reverse_match_service
  @reverse_match_service
end

Class Method Details

.broader_topsObject



376
377
378
379
380
381
# File 'app/models/concept/base.rb', line 376

def self.broader_tops
  includes(:narrower_relations, :pref_labels).
  where(concept_relations: { id: nil },
    labelings: { type: Iqvoc::Concept.pref_labeling_class_name }).
  order(Arel.sql("LOWER(#{Label::Base.table_name}.value)"))
end

.dashboard_pathObject



418
419
420
# File 'app/models/concept/base.rb', line 418

def self.dashboard_path
  'dashboard_path'
end


414
415
416
# File 'app/models/concept/base.rb', line 414

def self.edit_link_partial_name
  'partials/concept/edit_link_base'
end

.for_dashboardObject



395
396
397
# File 'app/models/concept/base.rb', line 395

def self.for_dashboard
  unpublished_or_follow_up.includes(:pref_labels)
end

.inline_partial_nameObject

********** Class methods



406
407
408
# File 'app/models/concept/base.rb', line 406

def self.inline_partial_name
  'partials/concept/inline_base'
end


410
411
412
# File 'app/models/concept/base.rb', line 410

def self.new_link_partial_name
  'partials/concept/new_link_base'
end

.parentlessObject



399
400
401
402
403
# File 'app/models/concept/base.rb', line 399

def self.parentless
  includes(:broader_relations)
    .where(concept_relations: {owner_id: nil}, top_term: false)
    .references(:concept_relations)
end

.topsObject

********** Scopes



372
373
374
# File 'app/models/concept/base.rb', line 372

def self.tops
  where(top_term: true)
end

.with_associationsObject



383
384
385
386
387
# File 'app/models/concept/base.rb', line 383

def self.with_associations
  includes([
    { labelings: :target }, :relations, :matches, :notes, :notations
  ])
end

.with_pref_labelsObject



389
390
391
392
393
# File 'app/models/concept/base.rb', line 389

def self.with_pref_labels
  preload(:pref_labels)
    .joins(:pref_labels)
    .order(Arel.sql("LOWER(#{Label::Base.table_name}.value)"))
end

Instance Method Details

#additional_infoObject

This shows up (in brackets) to the right of a concept link if it doesn't return nil



546
547
548
# File 'app/models/concept/base.rb', line 546

def additional_info
  nil
end

#assigned_collection_originsObject



469
470
471
# File 'app/models/concept/base.rb', line 469

def assigned_collection_origins
  @assigned_collection_origins || collections.map(&:origin).uniq
end

#assigned_collection_origins=(origins) ⇒ Object



464
465
466
467
# File 'app/models/concept/base.rb', line 464

def assigned_collection_origins=(origins)
  @assigned_collection_origins= origins.to_s
    .split(InlineDataHelper::SPLITTER).map(&:strip)
end

#associated_objects_in_editing_modeObject



558
559
560
561
562
# File 'app/models/concept/base.rb', line 558

def associated_objects_in_editing_mode
  {
    concept_relations: Concept::Relation::Base.by_owner(id).target_in_edit_mode,
  }
end

#class_pathObject

********** Methods



424
425
426
# File 'app/models/concept/base.rb', line 424

def class_path
  'concept_path'
end

#concept_relations_by_id(relation_name) ⇒ Object



453
454
455
456
457
# File 'app/models/concept/base.rb', line 453

def concept_relations_by_id(relation_name)
  (@concept_relations_by_id && @concept_relations_by_id[relation_name]) ||
    self.send(relation_name).map { |l| l.target.origin }.
    join(InlineDataHelper::JOINER)
end

#concept_relations_by_id=(hash) ⇒ Object



449
450
451
# File 'app/models/concept/base.rb', line 449

def concept_relations_by_id=(hash)
  @concept_relations_by_id = hash
end

#concept_relations_by_id_and_rank(relation_name) ⇒ Object



459
460
461
462
# File 'app/models/concept/base.rb', line 459

def concept_relations_by_id_and_rank(relation_name)
  self.send(relation_name).each_with_object({}) { |rel, hsh| hsh[rel.target] = rel.rank }
  # self.send(relation_name).map { |l| "#{l.target.origin}:#{l.rank}" }
end

#expired?Boolean

Returns:



569
570
571
# File 'app/models/concept/base.rb', line 569

def expired?
  self.expired_at && self.expired_at <= Date.today
end

#jobsObject



564
565
566
567
# File 'app/models/concept/base.rb', line 564

def jobs
  gid = self.to_global_id.to_s
  Delayed::Backend::ActiveRecord::Job.where(delayed_global_reference_id: gid)
end

#labelings_by_text(relation_name, language) ⇒ Object



442
443
444
445
446
447
# File 'app/models/concept/base.rb', line 442

def labelings_by_text(relation_name, language)
  (@labelings_by_text && @labelings_by_text[relation_name] &&
      @labelings_by_text[relation_name][language]) ||
      InlineDataHelper.generate_inline_values(self.send(relation_name).
          by_label_language(language).map { |l| l.target.value })
end

#labelings_by_text=(hash) ⇒ Object



428
429
430
431
432
433
434
435
436
437
438
439
440
# File 'app/models/concept/base.rb', line 428

def labelings_by_text=(hash)
  @labelings_by_text = hash

  @labelings_by_text.each do |relation_name, labels_by_lang|
    # if `language` is `nil`, the respective HTML form field returns an array
    # instead of a hash (`<input name=bla[labeling_class][]>`)
    if labels_by_lang.is_a?(Array)
      @labelings_by_text[relation_name] = { nil => labels_by_lang.first }
    end
  end

  @labelings_by_text
end

#labels_for_labeling_class_and_language(labeling_class, lang = :en, only_published = true) ⇒ Object



508
509
510
511
512
513
514
515
516
517
518
519
520
521
# File 'app/models/concept/base.rb', line 508

def labels_for_labeling_class_and_language(labeling_class, lang = :en, only_published = true)
  # Convert lang to string in case it's not nil.
  # nil values play their own role for labels without a language.
  if lang == 'none'
    lang = nil
  elsif lang
    lang = lang.to_s
  end
  labeling_class = labeling_class.name if labeling_class < ApplicationRecord # Use the class name string
  @labels ||= labelings.each_with_object({}) do |labeling, hash|
    ((hash[labeling.class.name.to_s] ||= {})[labeling.target.language] ||= []) << labeling.target if labeling.target
  end
  ((@labels && @labels[labeling_class] && @labels[labeling_class][lang]) || []).select{ |l| l.published? || !only_published }
end

#matches_for_class(match_class) ⇒ Object



529
530
531
532
# File 'app/models/concept/base.rb', line 529

def matches_for_class(match_class)
  match_class = match_class.name if match_class < ApplicationRecord # Use the class name string
  matches.select{ |match| match.class.name == match_class }
end

#notations_for_class(notation_class) ⇒ Object



539
540
541
542
# File 'app/models/concept/base.rb', line 539

def notations_for_class(notation_class)
  notation_class = notation_class.name if notation_class < ApplicationRecord # Use the class name string
  notations.select{ |notation| notation.class.name == notation_class }
end

#notes_for_class(note_class) ⇒ Object



534
535
536
537
# File 'app/models/concept/base.rb', line 534

def notes_for_class(note_class)
  note_class = note_class.name if note_class < ApplicationRecord # Use the class name string
  notes.select{ |note| note.class.name == note_class }
end

#pref_labelObject

returns the (one!) preferred label of a concept for the requested language. lang can either be a (lowercase) string or symbol with the (ISO ....) two letter code of the language (e.g. :en for English, :fr for French, :de for German). If no prefLabel for the requested language exists, a new label will be returned (if you modify it, don't forget to save it afterwards!)



478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
# File 'app/models/concept/base.rb', line 478

def pref_label
  if pref_labels.loaded?
    # use select if association is already loaded
    @cached_pref_labels ||= pref_labels.select(&:published?).each_with_object({}) do |label, hash|
      if hash[label.language]
        Rails.logger.warn("Two pref_labels (#{hash[label.language]}, #{label}) for one language (#{label.language}). Taking the second one.")
      end
      hash[label.language] = label
    end
  else
    # use scope otherwise
    @cached_pref_labels ||= pref_labels.published.each_with_object({}) do |label, hash|
      if hash[label.language]
        Rails.logger.warn("Two pref_labels (#{hash[label.language]}, #{label}) for one language (#{label.language}). Taking the second one.")
      end
      hash[label.language] = label
    end
  end

  lang = I18n.locale.to_s == 'none' ? nil : I18n.locale.to_s

  if @cached_pref_labels[lang].nil?
    # Fallback to the main language
    @cached_pref_labels[lang] = pref_labels.select{ |l|
        l.language.to_s == Iqvoc::Concept.pref_labeling_languages.first.to_s
    }.first
  end
  @cached_pref_labels[lang]
end


523
524
525
526
527
# File 'app/models/concept/base.rb', line 523

def related_concepts_for_relation_class(relation_class, only_published = true)
  relation_class = relation_class.name if relation_class < ApplicationRecord # Use the class name string
  relations.select { |rel| rel.class.name == relation_class }.map(&:target).
      select { |c| c.published? || !only_published }.sort_by(&:pref_label)
end

#to_paramObject



550
551
552
# File 'app/models/concept/base.rb', line 550

def to_param
  "#{origin}"
end

#to_sObject



554
555
556
# File 'app/models/concept/base.rb', line 554

def to_s
  pref_label.to_s
end