Class: ExportsController
- Inherits:
-
ApplicationController
- Object
- ActionController::Base
- ApplicationController
- ExportsController
- Defined in:
- app/controllers/exports_controller.rb
Overview
Copyright 2011-2013 innoQ Deutschland GmbH
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Instance Method Summary collapse
Instance Method Details
#create ⇒ Object
32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'app/controllers/exports_controller.rb', line 32 def create export = Export.new(export_params) export.user = current_user export.token = srand if export.save filename = export.build_filename job = ExportJob.new(export, filename,export.file_type, export.default_namespace) Delayed::Job.enqueue(job) flash[:success] = t('txt.views.export.success') else flash[:error] = t('txt.views.export.error') end redirect_to exports_path end |
#destroy ⇒ Object
49 50 51 52 53 54 55 56 57 |
# File 'app/controllers/exports_controller.rb', line 49 def destroy export = Export.find(params[:id]) if export.destroy flash[:success] = t('txt.views.export.delete.success') else flash[:error] = t('txt.views.export.delete.error') end redirect_to exports_path end |
#download ⇒ Object
59 60 61 62 63 64 65 66 67 68 |
# File 'app/controllers/exports_controller.rb', line 59 def download export = Export.find(params[:export_id]) time = export.finished_at&.strftime('%Y-%m-%d_%H-%M') Rails.logger.debug("Try to serve export from: #{export.build_filename}") send_file export.build_filename, filename: "export-#{time}.#{export.file_type}" rescue ::ActionController::MissingFile => e flash[:error] = t('txt.views.export.missing_file') redirect_to exports_path end |
#index ⇒ Object
22 23 24 25 |
# File 'app/controllers/exports_controller.rb', line 22 def index @export = Export.new @exports = Export.order('id DESC') end |
#show ⇒ Object
27 28 29 30 |
# File 'app/controllers/exports_controller.rb', line 27 def show @export = Export.find(params[:id]) flash[:warning] = t('txt.views.export.success') unless @export.finished_at? end |