Class: Label::Base

Inherits:
ApplicationRecord
  • Object
show all
Defined in:
app/models/label/base.rb

Overview

Copyright 2011-2013 innoQ Deutschland GmbH

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Direct Known Subclasses

Skos::Base

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.begins_with(prefix) ⇒ Object



80
81
82
83
84
85
# File 'app/models/label/base.rb', line 80

def self.begins_with(prefix)
  prefix = prefix.to_s
  table = Label::Base.table_name
  where("LOWER(SUBSTR(#{table}.value, 1, :length)) = :prefix",
      length: prefix.length, prefix: prefix.downcase)
end

.by_language(lang_code) ⇒ Object

********* Scopes



69
70
71
72
73
74
75
76
77
78
# File 'app/models/label/base.rb', line 69

def self.by_language(lang_code)
  lang_code = nil if lang_code.to_s == 'none'
  if (lang_code.is_a?(Array) && lang_code.include?('none'))
    where(arel_table[:language].eq(nil).or(arel_table[:language].in(lang_code.compact)))
  elsif lang_code.blank?
    where(arel_table[:language].eq(nil))
  else
    where(language: lang_code)
  end
end

.by_query_value(query) ⇒ Object



102
103
104
# File 'app/models/label/base.rb', line 102

def self.by_query_value(query)
  where(["#{table_name}.value ILIKE ?", query.to_s.downcase])
end

.missing_translation(lang, main_lang) ⇒ Object



87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'app/models/label/base.rb', line 87

def self.missing_translation(lang, main_lang)
  joins(:concepts).
  joins(sanitize_sql(["LEFT OUTER JOIN labelings pref_labelings ON
      pref_labelings.id <> labelings.id AND
      pref_labelings.owner_id = concepts.id AND
      pref_labelings.type = '%s'", Iqvoc::Concept.pref_labeling_class_name])).
  joins(sanitize_sql(["LEFT OUTER JOIN labels pref_labels ON
      pref_labels.id = pref_labelings.target_id AND
      pref_labels.language = '%s'", lang])).
  where('labelings.type = :class_name', class_name: Iqvoc::Concept.pref_labeling_class_name).
  where('pref_labels.id IS NULL').
  where('labels.language = :lang', lang: main_lang).
  includes(:pref_labeled_concepts)
end

.publishedObject

Attention: This means that even label classes without version controll will also have to set the published_at flag to be recognized as published!



108
109
110
# File 'app/models/label/base.rb', line 108

def self.published
  where(arel_table[:published_at].not_eq(nil))
end

.unpublishedObject



112
113
114
# File 'app/models/label/base.rb', line 112

def self.unpublished
  where(arel_table[:published_at].eq(nil))
end

Instance Method Details

#<=>(other) ⇒ Object



126
127
128
# File 'app/models/label/base.rb', line 126

def <=>(other)
  self.to_s.downcase <=> other.to_s.downcase
end

#==(other) ⇒ Object



130
131
132
# File 'app/models/label/base.rb', line 130

def ==(other)
  language == other.try(:language) && value == other.try(:value)
end

#eql?(other) ⇒ Boolean

Returns:

  • (Boolean)


134
135
136
# File 'app/models/label/base.rb', line 134

def eql?(other)
  self == other
end

#expired?Boolean

Returns:

  • (Boolean)


122
123
124
# File 'app/models/label/base.rb', line 122

def expired?
  self.expired_at && self.expired_at < Date.today
end

#hashObject



138
139
140
# File 'app/models/label/base.rb', line 138

def hash
  [value, language].hash
end

#published?Boolean

********* Methods

Returns:

  • (Boolean)


118
119
120
# File 'app/models/label/base.rb', line 118

def published?
  true
end

#to_literalObject



142
143
144
# File 'app/models/label/base.rb', line 142

def to_literal
  "\"#{value}\"@#{language}"
end

#to_sObject



146
147
148
# File 'app/models/label/base.rb', line 146

def to_s
    value.to_s
end