Class: Collection::Base
Overview
Copyright 2011-2013 innoQ Deutschland GmbH
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
Instance Attribute Summary
#reverse_match_service
Class Method Summary
collapse
Instance Method Summary
collapse
#additional_info, #assigned_collection_origins, #assigned_collection_origins=, #associated_objects_in_editing_mode, broader_tops, #concept_relations_by_id, #concept_relations_by_id=, #concept_relations_by_id_and_rank, #expired?, for_dashboard, #jobs, #labelings_by_text, #labelings_by_text=, #labels_for_labeling_class_and_language, #matches_for_class, #notations_for_class, #notes_for_class, parentless, #pref_label, #related_concepts_for_relation_class, #to_s, with_associations
#distinct_versions, #origin_has_to_be_escaped
#exclusive_broader_and_narrower_concepts, #exclusive_hidden_labels_per_concept, #exclusive_pref_and_alt_labels_per_concept, #exclusive_top_term, #no_self_reference_concept_relation, #pref_label_in_primary_thesaurus_language, #rooted_top_terms, #unique_alt_labels, #unique_pref_label_language, #unique_pref_labels, #valid_rank_for_ranked_relations
Methods included from Versioning
#branch, #disable_validations_for_publishing, #editor_selectable?, #enable_validations_for_publishing, #in_review?, #never_published?, #publish, #publish!, #publishable?, #published?, #state, #to_review, #unpublish, #unpublished?, #validatable_for_publishing?, #with_validations_for_publishing
Class Method Details
.by_label_value(val) ⇒ Object
75
76
77
|
# File 'app/models/collection/base.rb', line 75
def self.by_label_value(val)
includes(:labels).merge(Label::Base.by_query_value(val))
end
|
.by_origin(origin) ⇒ Object
71
72
73
|
# File 'app/models/collection/base.rb', line 71
def self.by_origin(origin)
where(origin: origin)
end
|
.by_parent_id(parent_id) ⇒ Object
84
85
86
87
|
# File 'app/models/collection/base.rb', line 84
def self.by_parent_id(parent_id)
includes(:parent_collection_members).
where(Collection::Member::Base.arel_table[:collection_id].eq(parent_id))
end
|
.dashboard_path ⇒ Object
89
90
91
|
# File 'app/models/collection/base.rb', line 89
def self.dashboard_path
'collection_dashboard_path'
end
|
.edit_link_partial_name ⇒ Object
97
98
99
|
# File 'app/models/collection/base.rb', line 97
def self.edit_link_partial_name
'partials/collection/edit_link_base'
end
|
.inline_partial_name ⇒ Object
93
94
95
|
# File 'app/models/collection/base.rb', line 93
def self.inline_partial_name
'partials/collection/inline_base'
end
|
.new_link_partial_name ⇒ Object
101
102
103
|
# File 'app/models/collection/base.rb', line 101
def self.new_link_partial_name
'partials/collection/new_link_base'
end
|
.tops ⇒ Object
79
80
81
82
|
# File 'app/models/collection/base.rb', line 79
def self.tops
includes(:parent_collection_members).
where("#{Collection::Member::Base.table_name}.target_id IS NULL")
end
|
.with_pref_labels ⇒ Object
64
65
66
67
68
69
|
# File 'app/models/collection/base.rb', line 64
def self.with_pref_labels
preload(:pref_labels)
.joins(:pref_labels)
.references(:collection_members)
.distinct
end
|
Instance Method Details
#build_rdf_subject(&block) ⇒ Object
117
118
119
|
# File 'app/models/collection/base.rb', line 117
def build_rdf_subject(&block)
IqRdf.build_uri(self.origin, IqRdf::Skos::build_uri('Collection'), &block)
end
|
#circular_subcollections ⇒ Object
This only prevent circles of length 2.
TODO: This should be a real circle detector (but still performant) or be
removed (seems to me like the better idea).
190
191
192
193
194
195
196
197
|
# File 'app/models/collection/base.rb', line 190
def circular_subcollections
Iqvoc::Collection.base_class.by_origin(@member_collection_origins).includes(members: :target).each do |subcollection|
if subcollection.subcollections.include?(self)
errors.add(:base,
I18n.t('txt.controllers.collections.circular_error', label: subcollection.pref_label))
end
end
end
|
#class_path ⇒ Object
105
106
107
|
# File 'app/models/collection/base.rb', line 105
def class_path
'collection_path'
end
|
#inline_member_collection_origins ⇒ Object
143
144
145
|
# File 'app/models/collection/base.rb', line 143
def inline_member_collection_origins
@member_collection_origins || subcollections.map(&:origin).uniq
end
|
#inline_member_collection_origins=(origins) ⇒ Object
138
139
140
141
|
# File 'app/models/collection/base.rb', line 138
def inline_member_collection_origins=(origins)
@member_collection_origins = origins.to_s.
split(InlineDataHelper::SPLITTER).map(&:strip)
end
|
#inline_member_collections ⇒ Object
147
148
149
150
151
152
153
|
# File 'app/models/collection/base.rb', line 147
def inline_member_collections
if @member_collection_origins
Collection::Base.where(origin: @member_collection_origins)
else
subcollections
end
end
|
#inline_member_concept_origins ⇒ Object
126
127
128
|
# File 'app/models/collection/base.rb', line 126
def inline_member_concept_origins
@member_concept_origins || concepts.map { |m| m.origin }.uniq
end
|
#inline_member_concept_origins=(origins) ⇒ Object
121
122
123
124
|
# File 'app/models/collection/base.rb', line 121
def inline_member_concept_origins=(origins)
@member_concept_origins = origins.to_s.
split(InlineDataHelper::SPLITTER).map(&:strip)
end
|
#inline_member_concepts ⇒ Object
130
131
132
133
134
135
136
|
# File 'app/models/collection/base.rb', line 130
def inline_member_concepts
if @member_concept_origins
Concept::Base.editor_selectable.where(origin: @member_concept_origins)
else
concepts.select{ |c| c.editor_selectable? }
end
end
|
#label ⇒ Object
113
114
115
|
# File 'app/models/collection/base.rb', line 113
def label
pref_label
end
|
#regenerate_collection_members ⇒ Object
181
182
183
|
# File 'app/models/collection/base.rb', line 181
def regenerate_collection_members
regenerate_members(Collection::Base, @member_collection_origins)
end
|
#regenerate_concept_members ⇒ Object
177
178
179
|
# File 'app/models/collection/base.rb', line 177
def regenerate_concept_members
regenerate_members(Concept::Base, @member_concept_origins)
end
|
#regenerate_members(target_class, target_origins) ⇒ Object
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
|
# File 'app/models/collection/base.rb', line 155
def regenerate_members(target_class, target_origins)
return if target_origins.nil? existing = self.members.includes(:target)
existing = if target_class <= Collection::Base
existing.select { |m| m.target.is_a?(Collection::Base) }
else
existing.reject { |m| m.target.is_a?(Collection::Base) }
end
new = []
target_origins.each do |new_origin|
member = existing.find{ |m| m.target.origin == new_origin }
unless member
c = target_class.by_origin(new_origin).first
member = Iqvoc::Collection.member_class.create(collection: self, target: c) if c
end
new << member if member
end
(existing - new).each do |m|
m.destroy
end
end
|
#to_param ⇒ Object
109
110
111
|
# File 'app/models/collection/base.rb', line 109
def to_param
origin
end
|