Class: Concepts::AlphabeticalController
- Inherits:
-
ConceptsController
- Object
- ConceptsController
- Concepts::AlphabeticalController
- Includes:
- DatasetInitialization
- Defined in:
- app/controllers/concepts/alphabetical_controller.rb
Overview
Copyright 2011-2013 innoQ Deutschland GmbH
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Direct Known Subclasses
Instance Method Summary collapse
Methods included from DatasetInitialization
#datasets_as_json, #init_datasets
Instance Method Details
#index ⇒ Object
20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'app/controllers/concepts/alphabetical_controller.rb', line 20 def index :read, Concept::Base # only initilaize dataset if dataset param is set # prevent obsolet http request when using matches widget datasets = params[:dataset] ? init_datasets : [] identify_used_first_letters if dataset = datasets.detect { |dataset| dataset.name == params[:dataset] } query = params[:prefix].to_s.downcase @search_results = dataset.alphabetical_search(query, I18n.locale) || [] @search_results = Kaminari.paginate_array(@search_results).page(params[:page]) else # When in single query mode, AR handles ALL includes to be loaded by that # one query. We don't want that! So let's do it manually :-) includes = Iqvoc::Concept.base_class.default_includes if Iqvoc::Concept.note_classes.include?(Note::Skos::Definition) includes << Note::Skos::Definition.name.to_relation_name end search_results_size = find_labelings.count search_results = find_labelings.page(params[:page]) Iqvoc::Concept.pref_labeling_class.preload(search_results, owner: includes) @search_results = search_results.to_a.map { |pl| AlphabeticalSearchResult.new(pl) } @search_results = Kaminari.paginate_array(@search_results, total_count: search_results_size).page(params[:page]) end respond_to do |format| format.html { render :index, layout: with_layout? } end end |